#
# spec file for package ghc-rio
#
# Copyright (c) 2020 SUSE LINUX GmbH, Nuernberg, Germany.
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%global pkg_name rio
%bcond_with tests
Name:           ghc-%{pkg_name}
Version:        0.1.14.1
Release:        bp153.1.20
Summary:        A standard library for Haskell
License:        MIT
URL:            https://hackage.haskell.org/package/%{pkg_name}
Source0:        https://hackage.haskell.org/package/%{pkg_name}-%{version}/%{pkg_name}-%{version}.tar.gz
BuildRequires:  ghc-Cabal-devel
BuildRequires:  ghc-bytestring-devel
BuildRequires:  ghc-containers-devel
BuildRequires:  ghc-deepseq-devel
BuildRequires:  ghc-directory-devel
BuildRequires:  ghc-exceptions-devel
BuildRequires:  ghc-filepath-devel
BuildRequires:  ghc-hashable-devel
BuildRequires:  ghc-microlens-devel
BuildRequires:  ghc-mtl-devel
BuildRequires:  ghc-primitive-devel
BuildRequires:  ghc-process-devel
BuildRequires:  ghc-rpm-macros
BuildRequires:  ghc-text-devel
BuildRequires:  ghc-time-devel
BuildRequires:  ghc-typed-process-devel
BuildRequires:  ghc-unix-devel
BuildRequires:  ghc-unliftio-core-devel
BuildRequires:  ghc-unliftio-devel
BuildRequires:  ghc-unordered-containers-devel
BuildRequires:  ghc-vector-devel
%if %{with tests}
BuildRequires:  ghc-QuickCheck-devel
BuildRequires:  ghc-hspec-devel
%endif

%description
A standard library for Haskell.

%package devel
Summary:        Haskell %{pkg_name} library development files
Requires:       %{name} = %{version}-%{release}
Requires:       ghc-compiler = %{ghc_version}
Requires(post): ghc-compiler = %{ghc_version}
Requires(postun): ghc-compiler = %{ghc_version}

%description devel
This package provides the Haskell %{pkg_name} library development files.

%prep
%setup -q -n %{pkg_name}-%{version}

%build
%ghc_lib_build

%install
%ghc_lib_install

%check
%cabal_test

%post devel
%ghc_pkg_recache

%postun devel
%ghc_pkg_recache

%files -f %{name}.files
%license LICENSE

%files devel -f %{name}-devel.files
%doc ChangeLog.md README.md

%changelog
* Tue Mar 24 2020 psimons@suse.com
- Update rio to version 0.1.14.1.
  [#]# 0.1.14.1
  * Support `unliftio-core` 0.2
* Thu Feb 27 2020 psimons@suse.com
- Update rio to version 0.1.14.0.
  [#]# 0.1.14.0
  * Addition of `mkSimpleApp`
  * Addition of `lookupEnvFromContext`
* Sat Jan 18 2020 psimons@suse.com
- Update rio to version 0.1.13.0.
  [#]# 0.1.13.0
  * Add `withLazyFileUtf8`
  * Add `mapRIO`
  * Add generic logger
  * Add `exeExtensions` and improve `findExecutable` on Windows [#205](https://github.com/commercialhaskell/rio/issues/205)
* Fri Nov  8 2019 Peter Simons <psimons@suse.com>
- Drop obsolete group attributes.
* Tue Aug 27 2019 psimons@suse.com
- Update rio to version 0.1.12.0.
  [#]# 0.1.12.0
  * Add `logFormat` and `setLogFormat` for `LogOptions`.
* Tue Jul 16 2019 psimons@suse.com
- Update rio to version 0.1.11.0.
  [#]# 0.1.11.0
  * Replace atomic and durable file writing functions with the ones from `unliftio`, see [#167](https://github.com/commercialhaskell/rio/pull/167)
* Tue Jul  2 2019 psimons@suse.com
- Update rio to version 0.1.10.0.
  [#]# 0.1.10.0
  * Relax a bunch of `RIO.File` functions from `MonadUnliftIO` to `MonadIO`
  * Custom `Monoid` instance for `Utf8Builder` that matches semantics of the
    derived one, but doesn't break list fusion
  * Qualified import recommendations for `*.Partial`, `*.Unchecked`, `*.Unsafe`
  * Re-export `Data.Ord.Down` from `RIO.Prelude`
  * Addition of `RIO.NonEmpty` module
  * Addition of `RIO.NonEmpty.Partial` module
  * Export `NonEmpty` type and its constructor `(:|)` from RIO.Prelude.Types
  * Fix handling of non-ASCII characters in `logSticky`
  * Deprecate `withProcess` and `withProcess_`, add `withProcessWait`, `withProcessWait_`, `withProcessTerm`, and `withProcessTerm_`
* Tue Apr 16 2019 psimons@suse.com
- Update rio to version 0.1.9.2.
  [#]# 0.1.9.2
  * Bring back re-export of `Monad.fail` from `RIO.Prelude`.
* Sun Apr 14 2019 psimons@suse.com
- Update rio to version 0.1.9.1.
  [#]# 0.1.9.1
  * Remove accidental reexport of `Control.Applicative.empty` introduced in the previous release.
  * Functions from `Data.Data.Data` class are brought to the re-export list as well.
* Sat Apr 13 2019 psimons@suse.com
- Update rio to version 0.1.9.0.
  [#]# 0.1.9.0
  * Add `Prelude.Exit` to export lifted versions of the exit functions from `System.Exit`.
  * Re-export the `Control.Monad.State.State` and `Control.Monad.State.StateT` types and related computation functions in `RIO.State`.
  * Re-export the `Control.Monad.Writer.Writer` and `Control.Monad.Writer.WriterT` types and related computation functions in `RIO.Writer`.
  * Re-export `pred`, `succ` in `RIO.Partial`.
  * Add `Semigroup` and `Monoid` instances for `RIO`
  * Add the `Deque` double-ended queue data type
  * Re-export `Data.Map.Strict.toAscList` and `Data.Map.Strict.toDescList` from `RIO.Map`.
  * Re-export `Data.Sequence.Seq` from `RIO`.
  * Addition of `RIO.Prelude` module
  * Addition of `RIO.Prelude.Types` module
  * Re-export `zipWith` and `runST` from `RIO.Prelude`
  * Re-export `Exception`, `MonadFail`, `Typeable` and `ST` from `RIO.Prelude.Types`
  * Switch to `MonadFail.fail` from `Monad.fail` and re-exported it from `RIO.Prelude`
* Mon Dec 31 2018 psimons@suse.com
- Update rio to version 0.1.8.0.
  [#]# 0.1.8.0
  * Re-export `Control.Monad.State.modify`, `Control.Monad.State.modify'` and `Control.Monad.State.gets` in `RIO.State`
* Fri Dec 28 2018 psimons@suse.com
- Update rio to version 0.1.7.0.
  [#]# 0.1.7.0
  * Addition of `textDisplay` to `Display` class.
* Sat Dec  8 2018 psimons@suse.com
- Update rio to version 0.1.6.0.
  [#]# 0.1.6.0
  * Changed `logUseColor` to default to `False` on Windows, even when verbose and on the terminal
  * Add `RIO.File` module which offers a family of file handling functions
    (`withBinaryFileDurable`, `withBinaryFileDurableAtomic`, among others.) with
    better durability and atomicity guarantees
* Sat Oct 20 2018 Peter Simons <psimons@suse.com>
- Use https URL to refer to bugs.opensuse.org.
* Thu Aug  2 2018 psimons@suse.com
- Update rio to version 0.1.5.0.
  [#]# 0.1.5.0
  * Re-export `Numeric.Natural.Natural` [#119](https://github.com/commercialhaskell/rio/issues/119)
  * Re-export `Data.Functor.<&>` from GHC 8.4+, falling back local definition for `base < 4.11` [#117](https://github.com/commercialhaskell/rio/issues/117)
  * Re-export `Data.Proxy.Proxy(..)`
  * Re-export `fromEnum` from RIO, export `toEnum`, `read` and `fromJust` from RIO.Partial
  * Add `noLogging` function to skip logging on specific sub-routines
  * Re-export `Control.Category.>>>`
* Fri Jul 13 2018 psimons@suse.com
- Update rio to version 0.1.4.0.
  [#]# 0.1.4.0
  * Add `Const` and `Identity`
  * Add `Reader` and `runReader`
  * Add instances for `MonadWriter` and `MonadState` to `RIO` via mutable reference [#103](https://github.com/commercialhaskell/rio/issues/103)
  [#]# 0.1.3.0
  * Add `newLogFunc` function to create `LogFunc` records outside of a callback scope
  * Allow dynamic reloading of `logMinLevel` and `logVerboseFormat` for the `LogOptions` record
  * Add `foldMapM`
  * Add `headMaybe`, `lastMaybe`, `tailMaybe`, `initMaybe`, `maximumMaybe`, `minimumMaybe`,
    `maximumByMaybe`, `minimumByMaybe` functions to `RIO.List` module (issue #82)
  * Move non partial functions `scanr1` and `scanl1` from `RIO.List.Partial` to `RIO.List` (issue #82)
  * Add `SimpleApp` and `runSimpleApp`
  * Add `asIO`
* Mon May 14 2018 psimons@suse.com
- Add rio at version 0.1.2.0.
